@@ -76,8 +76,7 @@ without triggering a rebuild. This can be better than passing a list to the Comm
 few special cases:
 
 1. PyScons enables parallel execution of a multistep submodule(if you pass the -j option to the spawned scons) 
-2. PyScons creates a workflow environment (like Pipeline Pilot) in scons which enables complex tasks to be packaged in scons files for
-use in other scons files.
+2. PyScons creates a workflow environment (like Pipeline Pilot) in scons which enables complex tasks to be packaged in scons files for use in other scons files.
 3. PyScons can turn intermediate file deletion on and off with a single flag::
 
     PyScons(targets, sources, "my_scons.py", clean = True) # intermediate file deleted
